@@ -14,13 +14,11 @@ declare(strict_types=1);
 namespace League\Csv;
 
 use ArrayIterator;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\TestCase;
 use function array_map;
-use function iterator_to_array;
 
-/**
- * @coversDefaultClass \League\Csv\MapIterator
- */
+#[Group('csv')]
 final class MapIteratorTest extends TestCase
 {
     public function testMapIteratorCanActLikeArrayMapWithOneArray(): void
@@ -31,7 +29,7 @@ final class MapIteratorTest extends TestCase
 
         self::assertSame(
             array_map($mapper, $array),
-            iterator_to_array(new MapIterator($iterator, $mapper), true)
+            [...new MapIterator($iterator, $mapper)]
         );
     }
 
@@ -44,9 +42,6 @@ final class MapIteratorTest extends TestCase
         $iterator = new ArrayIterator(['foo' => 'bar', 'bar' => 'baz']);
         $mapper = fn (string $value, $offset): string =>  $offset.' => '.$value;
 
-        self::assertSame(
-            $expected,
-            iterator_to_array(new MapIterator($iterator, $mapper), true)
-        );
+        self::assertSame($expected, [...new MapIterator($iterator, $mapper)]);
     }
 }
