@@ -9,8 +9,12 @@
  * file that was distributed with this source code.
  */
 
+declare(strict_types=1);
+
 namespace League\Csv;
 
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\TestCase;
 use SplFileObject;
 use SplTempFileObject;
@@ -19,14 +23,10 @@ use function count;
 use function fclose;
 use function fopen;
 use function fputcsv;
-use function iterator_to_array;
 use function json_encode;
 use function unlink;
 
-/**
- * @group reader
- * @coversDefaultClass \League\Csv\Reader
- */
+#[Group('reader')]
 final class ReaderTest extends TestCase
 {
     private Reader $csv;
@@ -50,11 +50,6 @@ final class ReaderTest extends TestCase
         unset($this->csv);
     }
 
-    /**
-     * @covers ::count
-     * @covers ::computeHeader
-     * @covers ::getRecords
-     */
     public function testCountable(): void
     {
         $source = '"parent name","child name","title"
@@ -65,9 +60,6 @@ final class ReaderTest extends TestCase
         self::assertCount(1, $csv);
     }
 
-    /**
-     * @covers ::getDocument
-     */
     public function testReaderWithEmptyEscapeChar1(): void
     {
         $source = <<<EOF
@@ -85,9 +77,6 @@ EOF;
         self::assertCount(4, $csv);
     }
 
-    /**
-     * @covers ::getDocument
-     */
     public function testReaderWithEmptyEscapeChar2(): void
     {
         $source = '"parent name","child name","title"
@@ -99,13 +88,6 @@ EOF;
         self::assertCount(1, $csv);
     }
 
-    /**
-     * @covers ::resetProperties
-     * @covers ::computeHeader
-     * @covers ::getIterator
-     * @covers ::getRecords
-     * @covers ::combineHeader
-     */
     public function testGetIterator(): void
     {
         $this->csv->setHeaderOffset(0);
@@ -124,10 +106,6 @@ EOF;
         }
     }
 
-    /**
-     * @covers ::computeHeader
-     * @covers ::combineHeader
-     */
     public function testCombineHeader(): void
     {
         $this->csv->setHeaderOffset(1);
@@ -136,13 +114,6 @@ EOF;
         }
     }
 
-    /**
-     * @covers ::setHeaderOffset
-     * @covers ::getHeaderOffset
-     * @covers ::getHeader
-     * @covers ::setHeader
-     * @covers ::seekRow
-     */
     public function testGetHeader(): void
     {
         $this->csv->setHeaderOffset(1);
@@ -154,13 +125,6 @@ EOF;
         self::assertSame([], $this->csv->getHeader());
     }
 
-    /**
-     * @covers ::fetchColumn
-     * @covers ::fetchColumnByName
-     * @covers ::fetchColumnByOffset
-     * @covers ::fetchOne
-     * @covers ::fetchPairs
-     */
     public function testCall(): void
     {
         $raw = [
@@ -179,21 +143,12 @@ EOF;
         $csv->setHeaderOffset(0);
 
         $res = Statement::create()->process($csv);
-        self::assertEquals($csv->fetchOne(3), $res->fetchOne(3));
-        self::assertEquals($csv->fetchColumn('firstname'), $res->fetchColumn('firstname'));
+        self::assertEquals($csv->nth(3), $res->nth(3));
         self::assertEquals($csv->fetchColumnByName('firstname'), $res->fetchColumnByName('firstname'));
         self::assertEquals($csv->fetchColumnByOffset(1), $res->fetchColumnByOffset(1));
         self::assertEquals($csv->fetchPairs('lastname', 0), $res->fetchPairs('lastname', 0));
     }
 
-    /**
-     * @covers ::getHeader
-     * @covers ::computeHeader
-     * @covers ::getRecords
-     * @covers ::setHeader
-     * @covers \League\Csv\SyntaxError::dueToDuplicateHeaderColumnNames
-     * @covers \League\Csv\SyntaxError::duplicateColumnNames
-     */
     public function testHeaderThrowsExceptionOnError(): void
     {
         $csv = Reader::createFromString(
@@ -203,20 +158,12 @@ EOF;
         );
         $csv->setHeaderOffset(0);
         self::assertSame(['field1', 'field1', 'field3'], $csv->getHeader());
-        try {
-            iterator_to_array($csv);
-        } catch (SyntaxError $exception) {
-            self::assertSame(['field1'], $exception->duplicateColumnNames());
-        }
+
+        $this->expectExceptionObject(SyntaxError::dueToDuplicateHeaderColumnNames(['field1']));
+
+        [...$csv];
     }
 
-    /**
-     * @covers ::getHeader
-     * @covers ::seekRow
-     * @covers ::setHeaderOffset
-     * @covers \League\Csv\SyntaxError::dueToHeaderNotFound
-     * @covers \League\Csv\SyntaxError::duplicateColumnNames
-     */
     public function testHeaderThrowsExceptionOnEmptyLine(): void
     {
         $str = <<<EOF
@@ -234,27 +181,14 @@ EOF;
         }
     }
 
-    /**
-     * @covers ::getHeader
-     * @covers ::computeHeader
-     * @covers ::setHeaderOffset
-     * @covers \League\Csv\SyntaxError::dueToInvalidHeaderColumnNames
-     */
     public function testHeaderThrowsIfItContainsNonStringNames(): void
     {
         $this->expectException(SyntaxError::class);
 
-        iterator_to_array($this->csv->getRecords(['field1', 2, 'field3']));
+        [...$this->csv->getRecords(['field1', 2, 'field3'])];
     }
 
-    /**
-     * @covers ::stripBOM
-     * @covers ::removeBOM
-     * @covers ::combineHeader
-     * @covers \League\Csv\Stream
-     *
-     * @dataProvider validBOMSequences
-     */
+    #[DataProvider('validBOMSequences')]
     public function testStripBOM(array $record, string $expected_bom, string $expected): void
     {
         /** @var resource $fp */
@@ -270,7 +204,7 @@ EOF;
         $fp = null;
     }
 
-    public function validBOMSequences(): array
+    public static function validBOMSequences(): array
     {
         return [
             'withBOM' => [
@@ -291,12 +225,6 @@ EOF;
         ];
     }
 
-    /**
-     * @covers ::stripBOM
-     * @covers ::removeBOM
-     * @covers ::combineHeader
-     * @covers \League\Csv\Stream
-     */
     public function testStripBOMWithEnclosure(): void
     {
         $source = Reader::BOM_UTF8.'"parent name","child name","title"
@@ -309,12 +237,6 @@ EOF;
         }
     }
 
-    /**
-     * @covers ::stripBOM
-     * @covers ::removeBOM
-     * @covers ::combineHeader
-     * @covers \League\Csv\Stream
-     */
     public function testStripNoBOM(): void
     {
         $source = '"parent name","child name","title"
@@ -344,10 +266,7 @@ EOF;
         $fp = null;
     }
 
-    /**
-     * @covers ::getIterator
-     * @dataProvider appliedFlagsProvider
-     */
+    #[DataProvider('appliedFlagsProvider')]
     public function testAppliedFlags(int $flag, int $fetch_count): void
     {
         $path = __DIR__.'/../test_files/tmp.txt';
@@ -361,7 +280,7 @@ EOF;
         unlink($path);
     }
 
-    public function appliedFlagsProvider(): array
+    public static function appliedFlagsProvider(): array
     {
         return [
             'NONE' => [0, 2],
@@ -375,36 +294,18 @@ EOF;
         ];
     }
 
-    /**
-     * @covers ::setHeader
-     * @covers ::seekRow
-     *
-     * @covers \League\Csv\InvalidArgument::dueToInvalidHeaderOffset
-     */
     public function testGetHeaderThrowsExceptionWithNegativeOffset(): void
     {
         $this->expectException(InvalidArgument::class);
         $this->csv->setHeaderOffset(-3)->getRecords();
     }
 
-    /**
-     * @covers ::setHeader
-     * @covers ::seekRow
-     *
-     * @covers \League\Csv\SyntaxError::dueToHeaderNotFound
-     */
     public function testGetHeaderThrowsExceptionWithSplFileObject(): void
     {
         $this->expectException(SyntaxError::class);
         $this->csv->setHeaderOffset(23)->getRecords();
     }
 
-    /**
-     * @covers ::setHeader
-     * @covers ::seekRow
-     *
-     * @covers \League\Csv\SyntaxError::dueToHeaderNotFound
-     */
     public function testGetHeaderThrowsExceptionWithStreamObject(): void
     {
         $this->expectException(SyntaxError::class);
@@ -419,11 +320,6 @@ EOF;
         $csv->setHeaderOffset(23)->getRecords();
     }
 
-    /**
-     * @covers ::setHeaderOffset
-     *
-     * @covers \League\Csv\InvalidArgument::dueToInvalidHeaderOffset
-     */
     public function testSetHeaderThrowsExceptionOnWrongInputRange(): void
     {
         $this->expectException(InvalidArgument::class);
@@ -431,9 +327,6 @@ EOF;
         $this->csv->setHeaderOffset(-1);
     }
 
-    /**
-     * @covers ::computeHeader
-     */
     public function testMapRecordsFields(): void
     {
         $keys = ['firstname', 'lastname', 'email'];
@@ -443,9 +336,6 @@ EOF;
         }
     }
 
-    /**
-     * @covers ::jsonSerialize
-     */
     public function testJsonSerialize(): void
     {
         $expected = [
@@ -465,22 +355,13 @@ EOF;
         );
     }
 
-    /**
-     * @covers ::createFromPath
-     */
     public function testCreateFromPath(): void
     {
         $csv = Reader::createFromPath(__DIR__.'/../test_files/foo_readonly.csv');
         self::assertCount(1, $csv);
     }
 
-    /**
-     * @dataProvider sourceProvider
-     * @covers ::includeEmptyRecords
-     * @covers ::skipEmptyRecords
-     * @covers ::isEmptyRecordsIncluded
-     * @covers ::getRecords
-     */
+    #[DataProvider('sourceProvider')]
     public function testSkippingEmptyRecords(
         Reader $reader,
         array $expected_with_skipping,
@@ -516,7 +397,7 @@ EOF;
         }
     }
 
-    public function sourceProvider(): array
+    public static function sourceProvider(): array
     {
         $source = <<<EOF
 "parent name","child name","title"
@@ -597,7 +478,7 @@ CSV;
             'column 1' => 'cell11',
             'column 2' => 'cell12',
             'column 3' => 'cell13',
-        ], $csv->fetchOne(0));
+        ], $csv->first());
 
         $csv->includeEmptyRecords();
 
@@ -606,7 +487,7 @@ CSV;
             'column 1' => null,
             'column 2' => null,
             'column 3' => null,
-        ], $csv->fetchOne(0));
+        ], $csv->first());
     }
 
     public function testRemovingEmptyRecordsWithoutBOMString(): void
@@ -624,7 +505,7 @@ CSV;
             'column 1' => 'cell11',
             'column 2' => 'cell12',
             'column 3' => 'cell13',
-        ], $csv->fetchOne(0));
+        ], $csv->first());
 
         $csv->includeEmptyRecords();
 
@@ -633,7 +514,7 @@ CSV;
             'column 1' => null,
             'column 2' => null,
             'column 3' => null,
-        ], $csv->fetchOne(0));
+        ], $csv->first());
     }
 
     public function testGetHeaderThrowsIfTheFirstRecordOnlyContainsBOMString(): void
